@@ -87,7 +87,8 @@ CDaemon::CDaemon()
       iDeviceName = std::string("Generic PeerHood device");
     }
 
-  iChecksum = (long)getpid();
+	// TODO change to use UUID - which must be saved
+  iChecksum = (long)getpid() ^ gethostid();
   iChecksum = htonl(iChecksum);
 
   iDeviceNameLength = htonl(iDeviceName.length()+1);
@@ -1349,20 +1350,32 @@ bool CDaemon::LoadParameter(string& aParameter)
 {
   char* home;
   string line;
+  string path;
 
   if ((home = getenv("HOME")) == NULL) {
-    return false;
+  	path = string("/etc/default/phconfig");
+    //return false;
   }
-
-  string path(home);
-  path.append("/.phconfig");
-
+  else
+  {
+  	path = string(home);
+  	path.append("/.phconfig");
+  }
+  
+  struct stat st;
+  
+	if(stat(path.c_str(),&st) == -1)
+  {
+  	path.clear();
+  	path = std::string("/etc/default/phconfig");
+  }
+  
   ifstream in(path.c_str());
 
   if (!in.is_open()) {
-    ERR("Failed to open the configuration file $HOME/.phconfig");
+    ERR("Failed to open the configuration file, using /etc/default/phconfig");
     in.close();
-    return false;
+   	return false;
   }
 
   while (!in.eof()) {
