@@ -30,6 +30,8 @@
 #include <stdio.h>
 #include <sys/ioctl.h>
 #include <errno.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 #include <signal.h>
 #include <setjmp.h>
@@ -170,21 +172,33 @@ bool CWLANPlugin::LoadParameter(std::string& aParameter)
 {
 	char* home;
 	std::string line;
+	std::string path;
 
-	if ((home = getenv("HOME")) == NULL) {
-		return false;
-	}
+  if ((home = getenv("HOME")) == NULL) {
+  	path = "/etc/default/phconfig";
+    //return false;
+  }
+  else
+  {
+  	path = std::string(home);
+  	path.append("/.phconfig");
+  }
+  
+  struct stat st;
+  
+	if(stat(path.c_str(),&st) == -1)
+  {
+  	path.clear();
+  	path = std::string("/etc/default/phconfig");
+  }
 
-	std::string path(home);
-	path.append("/.phconfig");
+  std::ifstream in(path.c_str());
 
-	std::ifstream in(path.c_str());
-
-	if (!in.is_open()) {
-		ERR("Failed to open the configuration file $HOME/.phconfig");
-		in.close();
-		return false;
-	}
+  if (!in.is_open()) {
+    ERR("Failed to open the configuration file");
+    in.close();
+    return false;
+  }
 
 	while (!in.eof()) {
 		getline(in, line);
